Obtain posterior means and credible intervals of the effects.
bnpmediation(dataTreatment, dataControl, prior, mcmc, state, status = TRUE,
na.action, q = 2, NN = 10, n1 = 10, n0 = 10, extra.thin = 0,
seed = 12345)The observed data under Z=1
The observed data under Z=0
a list giving the prior information
a list giving the MCMC parameters
a list giving the current value of the parameters
a logical variable indicating whether this run is new (TRUE) or the continuation of a previous analysis (FALSE)
a function that indicates what should happen when the data contain NAs
A dimension of the observed data, i.e., number of covariates plus 2
Number of samples drawn for each iteration from the joint distribution of the mediator and the covariates. Default is 10
Number of observations under Z=1
Number of observations under Z=0
Giving the extra thinning interval
Value to be given to the seed
ENIE Posterior mean of the Natural Indirect Effect (NIE)
ENDE Posterior mean of the Natural Direct Effect (NDE)
ETE Posterior mean of the Total Effect (TE)
IE.c.i 95% C.I. of the NIE
DE.c.i 95% C.I. of the NDE
TE.c.i 95% C.I. of the TE
Y11 Posterior samples of Y11
Y00 Posterior samples of Y00
Y10 Posterior samples of Y10